@@ -1,4 +1,4 @@
-import engine
+from . import engine
 
 def main():
     from cli import args
